
From: Benjamin Herrenschmidt <benh@kernel.crashing.org>

This patch fixes a couple of warnings about possible uninitialized
variables in radeonfb, along with a small logic error in the monitor probe
code when nothing was found.

Signed-off-by: Benjamin Herrenschmidt <benh@kernel.crashing.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/video/aty/radeon_base.c    |    2 +-
 25-akpm/drivers/video/aty/radeon_monitor.c |    6 ++++--
 2 files changed, 5 insertions(+), 3 deletions(-)

diff -puN drivers/video/aty/radeon_base.c~radeonfb-fix-warnings-about-uninitialized-variables drivers/video/aty/radeon_base.c
--- 25/drivers/video/aty/radeon_base.c~radeonfb-fix-warnings-about-uninitialized-variables	2004-09-15 02:34:15.864313712 -0700
+++ 25-akpm/drivers/video/aty/radeon_base.c	2004-09-15 02:34:15.870312800 -0700
@@ -1868,7 +1868,7 @@ static int radeon_set_backlight_level(in
 #undef SET_MC_FB_FROM_APERTURE
 static void fixup_memory_mappings(struct radeonfb_info *rinfo)
 {
-	u32 save_crtc_gen_cntl, save_crtc2_gen_cntl;
+	u32 save_crtc_gen_cntl, save_crtc2_gen_cntl = 0;
 	u32 save_crtc_ext_cntl;
 	u32 aper_base, aper_size;
 	u32 agp_base;
diff -puN drivers/video/aty/radeon_monitor.c~radeonfb-fix-warnings-about-uninitialized-variables drivers/video/aty/radeon_monitor.c
--- 25/drivers/video/aty/radeon_monitor.c~radeonfb-fix-warnings-about-uninitialized-variables	2004-09-15 02:34:15.865313560 -0700
+++ 25-akpm/drivers/video/aty/radeon_monitor.c	2004-09-15 02:34:15.871312648 -0700
@@ -69,8 +69,10 @@ static int __devinit radeon_parse_montyp
 		mt = MT_DFP;
 	else if (!strcmp(pmt, "CRT"))
 		mt = MT_CRT;
-	else if (strcmp(pmt, "NONE")) {
-		printk(KERN_WARNING "radeonfb: Unknown OF display-type: %s\n", pmt);
+	else {
+		if (strcmp(pmt, "NONE") != 0)
+			printk(KERN_WARNING "radeonfb: Unknown OF display-type: %s\n",
+			       pmt);
 		return MT_NONE;
 	}
 	for (i = 0; propnames[i] != NULL; ++i) {
_
